@@ -14,9 +14,10 @@ class Command:
     def print(
         self,
         text: str,
-        end: str = "\n",
+        end: str = "\r\n",
         color: Optional[int] = None,
         force: bool = False,
+        flush: bool = False,
     ) -> None:
         if not self.quiet or force:
             if color is not None and os.isatty(sys.stderr.fileno()):
@@ -24,6 +25,9 @@ class Command:
 
             print(text, file=sys.stderr, end=end)
 
+            if flush:
+                sys.stderr.flush()
+
     def print_info(self, text: str) -> None:
         self.print(f"asciinema: {text}", color=2)
 
